ExponentialHistogram

Struct ExponentialHistogram 

pub struct ExponentialHistogram<T> { /* private fields */ }
An instrument that records a distribution of values.

ExponentialHistogram can be cloned to create multiple handles to the same instrument. If a ExponentialHistogram needs to be shared, users are recommended to clone the ExponentialHistogram instead of creating duplicate ExponentialHistograms for the same metric. Creating duplicate ExponentialHistograms for the same metric could lower SDK performance.

Implementations

Source

impl<T> ExponentialHistogram<T>

pub fn record(&self, value: T, attributes: &[KeyValue])

Adds an additional value to the distribution.